/* @@BEGIN_COPYRIGHT@@ */
/* IBM Confidential                                               */
/* Licensed Internal Code Source Materials                        */
/* 2964 2965 Licensed Internal Code                               */
/* (C) Copyright IBM Corp. 2000, 2016                             */
/* The source code for this program is not published or otherwise */
/* divested of its trade secrets, irrespective of what has        */
/* been deposited with the U.S. Copyright Office.                 */
/* @@END_COPYRIGHT@@ */
/*TITLE HWMCAAPI.H: Hardware Management Console API Include File      R000 V00*/
/******************************************************************************/
/*                                                                            */
/*  Module Name: HWMCAAPI.H                                                   */
/*                                                                            */
/*  Description: This is header file for the Hardware Management Console      */
/*               External APIs.                                               */
/*                                                                            */
/*  Copyright:   IBM Corporation 1999-2009                                    */
/*                                                                            */
/******************************************************************************/

#if !defined (HWMCAAPI_H)                     /* Only expand file once        */
#define HWMCAAPI_H                            /* per compilation.             */

#ifdef WIN32
#define EXPORTTYPE __declspec(dllexport) WINAPI
#else
#if defined(MVS) || defined(__VM__)
#define HWMCA_CODESET "IBM-850"
#endif
#if defined(MVS) || defined(UNIX)
#ifndef EXPORTTYPE
#define EXPORTTYPE
#endif
#ifndef HWMCA_SKIP_TYPEDEFS
#define CHAR    char
#define SHORT   short
#define LONG    long
#define INT     int
#define VOID    void
typedef void   * PVOID;
typedef unsigned char  UCHAR;
typedef unsigned short USHORT;
typedef unsigned int   UINT;
typedef unsigned long  ULONG;
typedef char * PSZ;
typedef unsigned int *  PUINT;
typedef unsigned long * PULONG;
#endif
#else
#define EXPORTTYPE EXPENTRY
#endif
#endif

/******************************************************************************/
/* Defines for the Hardware Management Console Data Exchange                  */
/* Return Code Values.                                                        */
/******************************************************************************/
#define HWMCA_DE_NO_ERROR             0
#define HWMCA_DE_NO_SUCH_OBJECT       1
#define HWMCA_DE_INVALID_DATA_TYPE    2
#define HWMCA_DE_INVALID_DATA_LENGTH  3
#define HWMCA_DE_INVALID_DATA_PTR     4
#define HWMCA_DE_INVALID_DATA_VALUE   5
#define HWMCA_DE_INVALID_INIT_PTR     6
#define HWMCA_DE_INVALID_ID_PTR       7
#define HWMCA_DE_INVALID_BUF_PTR      8
#define HWMCA_DE_INVALID_BUF_SIZE     9
#define HWMCA_DE_INVALID_DATATYPE_PTR 10
#define HWMCA_DE_INVALID_TARGET       11
#define HWMCA_DE_INVALID_EVENT_MASK   12
#define HWMCA_DE_INVALID_PARAMETER    13
#define HWMCA_DE_READ_ONLY_OBJECT     14
#define HWMCA_DE_SNMP_INIT_ERROR      15
#define HWMCA_DE_INVALID_OBJECT_ID    16
#define HWMCA_DE_REQUEST_ALLOC_ERROR  17
#define HWMCA_DE_REQUEST_SEND_ERROR   18
#define HWMCA_DE_TIMEOUT              19
#define HWMCA_DE_REQUEST_RECV_ERROR   20
#define HWMCA_DE_SNMP_ERROR           21
#define HWMCA_DE_INVALID_TIMEOUT      22
#define HWMCA_DE_OBJECT_BUSY          24
#define HWMCA_DE_INVALID_HOST         28
#define HWMCA_DE_INVALID_COMMUNITY    29
#define HWMCA_DE_INVALID_QUALIFIER    30
#define HWMCA_DE_PROTOCOL_ERROR       31
#define HWMCA_DE_INVALID_EVENT_ERROR  32
#define HWMCA_DE_INVALID_VARBIND_PTR  33
#define HWMCA_DE_PARTIAL_SUCCESS      34
#define HWMCA_DE_UNKNOWN_USERNAME     95
#define HWMCA_DE_INCORRECT_PASSWORD   96
#define HWMCA_DE_INVALID_STACKNAME    97
#define HWMCA_DE_REQUIRES_QUALIFIER   98
#define HWMCA_DE_TRANSPORT_ERROR      99

/******************************************************************************/
/* Defines for the Hardware Management Console Command Return Code Values.    */
/******************************************************************************/
#define HWMCA_CMD_NO_ERROR                          0
#define HWMCA_CMD_NO_SUCH_OBJECT                    1
#define HWMCA_CMD_INVALID_DATA_TYPE                 2
#define HWMCA_CMD_INVALID_DATA_LENGTH               3
#define HWMCA_CMD_INVALID_DATA_PTR                  4
#define HWMCA_CMD_INVALID_DATA_VALUE                5
#define HWMCA_CMD_INVALID_INIT_PTR                  6
#define HWMCA_CMD_INVALID_ID_PTR                    7
#define HWMCA_CMD_INVALID_DATATYPE_PTR              10
#define HWMCA_CMD_INVALID_PARAMETER                 13
#define HWMCA_CMD_REQUEST_ALLOC_ERROR               17
#define HWMCA_CMD_REQUEST_SEND_ERROR                18
#define HWMCA_CMD_TIMEOUT                           19
#define HWMCA_CMD_REQUEST_RECV_ERROR                20
#define HWMCA_CMD_SNMP_ERROR                        21
#define HWMCA_CMD_INVALID_TIMEOUT                   22
#define HWMCA_CMD_INVALID_CMD                       23
#define HWMCA_CMD_OBJECT_BUSY                       24
#define HWMCA_CMD_INVALID_OBJECT                    25
#define HWMCA_CMD_COMMAND_FAILED                    26
#define HWMCA_CMD_INITTERM_OK                       27
#define HWMCA_CMD_CBU_DISRUPTIVE_OK                 28
#define HWMCA_CMD_CBU_PARTIAL_HW                    29
#define HWMCA_CMD_CBU_NO_SPARES                     30
#define HWMCA_CMD_CBU_TEMPORARY                     31
#define HWMCA_CMD_CBU_NOT_ENABLED                   32
#define HWMCA_CMD_CBU_NOT_AUTHORIZED                33
#define HWMCA_CMD_CBU_FAILED                        34
#define HWMCA_CMD_CBU_ALREADY_ACTIVE                35
#define HWMCA_CMD_CBU_INPROGRESS                    36
#define HWMCA_CMD_CBU_CPSAP_SPLIT_CHG               37
#define HWMCA_CMD_INVALID_MACHINE_STATE             38
#define HWMCA_CMD_NO_RECORDID                       39
#define HWMCA_CMD_NO_SW_MODEL                       40
#define HWMCA_CMD_NOT_ENOUGH_RESOURCES              41
#define HWMCA_CMD_NOT_ENOUGH_ACTIVE_RESOURCES       42
#define HWMCA_CMD_ACT_LESS_RESOURCES                43
#define HWMCA_CMD_DEACT_MORE_RESOURCES              44
#define HWMCA_CMD_ACT_TYPE_MISMATCH                 45
#define HWMCA_CMD_API_NOT_ALLOWED                   46
#define HWMCA_CMD_CDU_IN_PROGRESS                   47
#define HWMCA_CMD_MIRRORING_RUNNING                 48
#define HWMCA_CMD_COMMUNICATIONS_NOT_ACTIVE         49
#define HWMCA_CMD_RECORD_EXPIRED                    50
#define HWMCA_CMD_PARTIAL_CAPACITY                  51
#define HWMCA_CMD_INVALID_REQUEST                   52
#define HWMCA_CMD_ALREADY_ACTIVE                    53
#define HWMCA_CMD_RESERVE_HELD                      54
#define HWMCA_CMD_GENERAL_XML_PARSING_ERROR         55
#define HWMCA_CMD_STP_NOT_ENABLED                   56
#define HWMCA_CMD_STP_MUST_TARGET_CTS               57
#define HWMCA_CMD_STP_INVALID_CONFIG_SPECIFIED      58
#define HWMCA_CMD_STP_WRONG_CTN                     59
#define HWMCA_CMD_STP_NOT_VALID_FOR_CTS             60
#define HWMCA_CMD_STP_IN_ETR_MIGRATION              61
#define HWMCA_CMD_STP_NODE_NOT_FOUND_IN_SYSTEM_LIST 62
#define HWMCA_CMD_STP_CTNID_TAG_ERROR               63
#define HWMCA_CMD_STP_NODE_TAG_ERROR                64
#define HWMCA_CMD_STP_CONFIG_TAG_NOT_FOUND          65
#define HWMCA_CMD_STP_ACTIVE_CTS_TAG_ERROR          66
#define HWMCA_CMD_STP_INITIALIZE_INCOMPLETE         67
#define HWMCA_CMD_STP_INVALID_STP_ID                68
#define HWMCA_CMD_STP_LINKS_ERROR                   69
#define HWMCA_CMD_STP_REQUIRES_FORCE_TO_CONFIGURE   70
#define HWMCA_CMD_PROCESSOR_POWER_MODE_NOT_ENTITLED 71
#define HWMCA_CMD_PROCESSOR_POWER_MODE_NOT_ALLOWED  72
#define HWMCA_CMD_PROCESSOR_POWER_MODE_GROUP_CONTROLLED 73

/******************************************************************************/
/* Defines for the Hardware Management Console Rexx I/F Return Code Values.   */
/******************************************************************************/
#define HWMCA_RX_INVALID_STEM_VAR      1000

/******************************************************************************/
/* Miscellaneous defines for the Hardware Management Console APIs.            */
/******************************************************************************/
#define HWMCA_INFINITE_WAIT        -1
#define HWMCA_MAX_ID_LEN           80
#define HWMCA_MAX_COMMUNITY_LEN    16
#define HWMCA_MAX_USERNAME_LEN     32
#define HWMCA_MIN_EVENT_BUF_SIZE   ((sizeof(HWMCA_DATATYPE_T)*2)+4+HWMCA_MAX_ID_LEN)
#define HWMCA_MAX_EVENT_BUF_SIZE   (HWMCA_MIN_EVENT_BUF_SIZE+4+9+8+9+4+4+4+9+4+4096+\
                                    (((sizeof(HWMCA_DATATYPE_T)*2)+HWMCA_MAX_ID_LEN)*11))
#define HWMCA_TRUE                 1
#define HWMCA_FALSE                0
#define HWMCA_API_PORT             3161

/******************************************************************************/
/* Defines for the Hardware Management Console Object Data Types.             */
/******************************************************************************/
#define HWMCA_TYPE_SEQUENCE        0x30
#define HWMCA_TYPE_OPAQUE_SEQUENCE 0x44
#define HWMCA_TYPE_INTEGER         0x02
#define HWMCA_TYPE_OCTETSTRING     0x04
#define HWMCA_TYPE_NULL            0x05
#define HWMCA_TYPE_OBJECTID        0x06
#define HWMCA_TYPE_IPADDRESS       0x40
#define HWMCA_TYPE_COUNTER         0x41
#define HWMCA_TYPE_GAUGE           0x42
#define HWMCA_TYPE_TIMETICKS       0x43

/******************************************************************************/
/* Defines for the Hardware Management Console Event Notification Types.      */
/******************************************************************************/
#define HWMCA_EVENT_COMMAND_RESPONSE               0x00000000
#define HWMCA_EVENT_MESSAGE                        0x00000001
#define HWMCA_EVENT_STATUS_CHANGE                  0x00000002
#define HWMCA_EVENT_NAME_CHANGE                    0x00000004
#define HWMCA_EVENT_ACTIVATE_PROF_CHANGE           0x00000008
#define HWMCA_EVENT_CREATED                        0x00000010
#define HWMCA_EVENT_DESTROYED                      0x00000020
#define HWMCA_EVENT_EXCEPTION_STATE                0x00000040
#define HWMCA_EVENT_ENDED                          0x00000080
#define HWMCA_EVENT_HARDWARE_MESSAGE               0x00000100
#define HWMCA_EVENT_OPSYS_MESSAGE                  0x00000200
#define HWMCA_EVENT_NO_REFRESH_MESSAGE             0x00000400
#define HWMCA_EVENT_STARTED                        0x00000800
#define HWMCA_EVENT_HARDWARE_MESSAGE_DELETE        0x00001000
#define HWMCA_EVENT_ALERT                          0x00002000
#define HWMCA_EVENT_SECURITY_EVENT                 0x00004000
#define HWMCA_EVENT_CAPACITY_CHANGE                0x00008000
#define HWMCA_EVENT_CAPACITY_RECORD_CHANGE         0x00010000
#define HWMCA_EVENT_DISABLED_WAIT                  0x00040000
#define HWMCA_EVENT_POWER_CHANGE                   0x00080000
#define HWMCA_EVENT_ALL_EVENTS                     0x000DFFFF

#define HWMCA_DIRECT_INITIALIZE                    0x20000000
#define HWMCA_FORCE_CLIENT_PATH                    0x10000000
#define HWMCA_SNMP_VERSION_2                       0x08000000
#define HWMCA_TOLERATE_LOST_EVENTS                 0x02000000
#define HWMCA_QUALIFIER_SPECIFIED                  0x00800000
#define HWMCA_SNMP_USING_TCP                       0x00400000
#define HWMCA_EVENT_NO_COMMAND_RESPONSE            0x00020000
#define HWMCA_EVENT_KEEP_ALIVE                     0x00200000

/******************************************************************************/
/* Defines for the Hardware Management Console Static Object IDs.             */
/******************************************************************************/
#define HWMCA_OBJECT_PREFIX             "1.3.6.1.4.1.2.6.42."
#define HWMCA_CONSOLE_ID                "1.3.6.1.4.1.2.6.42.0"    /* .x.x */
#define HWMCA_CFG_CPC_GROUP_ID          "1.3.6.1.4.1.2.6.42.1"    /* .x.x */
#define HWMCA_CFG_CPC_ID                "1.3.6.1.4.1.2.6.42.1.0"  /* .x.x.* */
#define HWMCA_CPC_IMAGE_GROUP_ID        "1.3.6.1.4.1.2.6.42.2"    /* .x.x */
#define HWMCA_CPC_IMAGE_ID              "1.3.6.1.4.1.2.6.42.2.0"  /* .x.x.* */
#define HWMCA_GROUPS_GROUP_ID           "1.3.6.1.4.1.2.6.42.3"    /* .x.x.* */
#define HWMCA_GROUPS_OBJECT_ID          "1.3.6.1.4.1.2.6.42.3.0"  /* .x.x.*.* */
#define HWMCA_COMMAND_PREFIX            "1.3.6.1.4.1.2.6.42.4."
#define HWMCA_ACT_RESET_OBJECT_ID       "1.3.6.1.4.1.2.6.42.5.0"  /* .x.x.*.* */
#define HWMCA_ACT_IMAGE_OBJECT_ID       "1.3.6.1.4.1.2.6.42.6.0"  /* .x.x.*.* */
#define HWMCA_ACT_LOAD_OBJECT_ID        "1.3.6.1.4.1.2.6.42.7.0"  /* .x.x.*.* */
#define HWMCA_ACT_GROUP_OBJECT_ID       "1.3.6.1.4.1.2.6.42.8.0"  /* .x.x.*.* */
#define HWMCA_CAPACITY_RECORD_OBJECT_ID "1.3.6.1.4.1.2.6.42.9.0"  /* .x.x.*.* */
#define HWMCA_CFG_VM_GROUP_ID           "1.3.6.1.4.1.2.6.42.10"   /* .x.x */
#define HWMCA_VM_OBJECT_ID              "1.3.6.1.4.1.2.6.42.10.0" /* .x.x.* */
#define HWMCA_ZBX_GROUP_ID              "1.3.6.1.4.1.2.6.42.11"   /* .x.x */
#define HWMCA_ZBX_ID                    "1.3.6.1.4.1.2.6.42.11.0" /* .x.x.*.* */
#define HWMCA_ZBX_CHASSIS_ID            "1.3.6.1.4.1.2.6.42.12.0" /* .x.x.*.* */

/******************************************************************************/
/* Defines for the Hardware Management Console Object Attribute ID suffixes.  */
/******************************************************************************/
#define HWMCA_COMMAND_OBJECT_ID_SUFFIX             "0.1"
#define HWMCA_COMMAND_CONDITION_CODE_SUFFIX        "0.2"
#define HWMCA_COMMAND_LAST_INDICATOR_SUFFIX        "0.3"
#define HWMCA_ENDED_REASON_SUFFIX                  "0.4"
#define HWMCA_ENDED_COMPONENT_SUFFIX               "0.5"
#define HWMCA_ENDED_TYPE_SUFFIX                    "0.6"
#define HWMCA_COMMAND_CORRELATOR_SUFFIX            "0.7"
#define HWMCA_NAME_SUFFIX                          "1.0"
#define HWMCA_PARENT_NAME_SUFFIX                   "2.0"
#define HWMCA_OPSYS_NAME_SUFFIX                    "3.0"
#define HWMCA_OPSYS_TYPE_SUFFIX                    "4.0"
#define HWMCA_OPSYS_LEVEL_SUFFIX                   "5.0"
#define HWMCA_SYSPLEX_NAME_SUFFIX                  "6.0"
#define HWMCA_STATUS_ERROR_SUFFIX                  "7.0"
#define HWMCA_BUSY_SUFFIX                          "8.0"
#define HWMCA_MESSAGE_SUFFIX                       "9.0"
#define HWMCA_MESSAGE_TYPE_SUFFIX                  "9.1"
#define HWMCA_MESSAGE_TEXT_SUFFIX                  "9.2"
#define HWMCA_MESSAGE_MSG_ID_SUFFIX                "9.3"
#define HWMCA_MESSAGE_DATE_SUFFIX                  "9.4"
#define HWMCA_MESSAGE_TIME_SUFFIX                  "9.5"
#define HWMCA_MESSAGE_ALARM_SUFFIX                 "9.6"
#define HWMCA_MESSAGE_PRIORITY_SUFFIX              "9.7"
#define HWMCA_MESSAGE_HELD_SUFFIX                  "9.8"
#define HWMCA_MESSAGE_PROMPT_TEXT_SUFFIX           "9.9"
#define HWMCA_MESSAGE_OSNAME_TEXT_SUFFIX           "9.10"
#define HWMCA_MESSAGE_REFRESH_SUFFIX               "9.11"
#define HWMCA_MESSAGE_TIMESTAMP                    "9.12"
#define HWMCA_MESSAGE_IMAGE_LIST                   "9.13"
#define HWMCA_STATUS_SUFFIX                        "10.0"
#define HWMCA_EXPECTED_STATUS_SUFFIX               "11.0"
#define HWMCA_IMLMODE_SUFFIX                       "12.0"
#define HWMCA_ACTIVATION_PROFILE_SUFFIX            "13.0"
#define HWMCA_LAST_ACT_PROFILE_SUFFIX              "14.0"
#define HWMCA_IP_ADDRESS_SUFFIX                    "15.0"
#define HWMCA_SNA_ADDRESS_SUFFIX                   "16.0"
#define HWMCA_MODEL_SUFFIX                         "17.0"
#define HWMCA_TYPE_SUFFIX                          "18.0"
#define HWMCA_MACHINE_SERIAL_SUFFIX                "19.0"
#define HWMCA_CPC_SERIAL_SUFFIX                    "20.0"
#define HWMCA_CPC_ID_SUFFIX                        "21.0"
#define HWMCA_OBJECT_TYPE_SUFFIX                   "22.0"
#define HWMCA_GROUP_CONTENTS_SUFFIX                "23.0"
#define HWMCA_ACT_RESET_LIST_SUFFIX                "24.0"
#define HWMCA_ACT_IMAGE_LIST_SUFFIX                "25.0"
#define HWMCA_ACT_LOAD_LIST_SUFFIX                 "26.0"
#define HWMCA_ACT_PROFILE_IOCDS_SUFFIX             "27.0"
#define HWMCA_ACT_PROFILE_IPLADDR_SUFFIX           "28.0"
#define HWMCA_ACT_PROFILE_IPLPARM_SUFFIX           "29.0"
#define HWMCA_WEIGHT_SUFFIX                        "30.0"
#define HWMCA_CAPPED_SUFFIX                        "31.0"
#define HWMCA_CBU_INSTALLED_SUFFIX                 "32.0"
#define HWMCA_CBU_ACTIVATED_SUFFIX                 "33.0"
#define HWMCA_CBU_ACTIVATION_DATE_SUFFIX           "34.0"
#define HWMCA_CBU_EXPIRATION_DATE_SUFFIX           "35.0"
#define HWMCA_NUMBER_CBU_TEST_LEFT_SUFFIX          "36.0"
#define HWMCA_REAL_CBU_ACTIVATION_AVAILABLE_SUFFIX "37.0"
#define HWMCA_MINIMUM_WEIGHT_SUFFIX                "38.0"
#define HWMCA_MAXIMUM_WEIGHT_SUFFIX                "39.0"
#define HWMCA_WLM_MANAGED_SUFFIX                   "40.0"
#define HWMCA_CURRENT_WEIGHT_SUFFIX                "41.0"
#define HWMCA_CURRENT_CAPPED_SUFFIX                "42.0"
#define HWMCA_DEFINED_CAPACITY_SUFFIX              "43.0"
#define HWMCA_RESERVE_ID_SUFFIX                    "44.0"
#define HWMCA_ALERT_SUFFIX                         "45.0"
#define HWMCA_SERVICE_REQUIRED_SUFFIX              "46.0"
#define HWMCA_DEGRADED_SUFFIX                      "47.0"
#define HWMCA_CBU_ENABLED_SUFFIX                   "48.0"
#define HWMCA_CLUSTER_NAME_SUFFIX                  "49.0"
#define HWMCA_CLUSTER_LIST_SUFFIX                  "50.0"
#define HWMCA_PARTITION_ID_SUFFIX                  "51.0"
#define HWMCA_ACT_PROFILE_IPLTYPE_SUFFIX           "52.0"
#define HWMCA_ACT_PROFILE_WWPN_SUFFIX              "53.0"
#define HWMCA_ACT_PROFILE_BPS_SUFFIX               "54.0"
#define HWMCA_ACT_PROFILE_LUN_SUFFIX               "55.0"
#define HWMCA_ACT_PROFILE_BRLBA_SUFFIX             "56.0"
#define HWMCA_ACT_PROFILE_OSLOADPARM_SUFFIX        "57.0"
#define HWMCA_EVENT_TEXT_SUFFIX                    "58.0"
#define HWMCA_EVENT_TIMESTAMP_SUFFIX               "59.0"
#define HWMCA_IFA_WEIGHT_SUFFIX                    "60.0"
#define HWMCA_IFA_CAPPED_SUFFIX                    "61.0"
#define HWMCA_IFA_MINIMUM_WEIGHT_SUFFIX            "62.0"
#define HWMCA_IFA_MAXIMUM_WEIGHT_SUFFIX            "63.0"
#define HWMCA_IFA_CURRENT_WEIGHT_SUFFIX            "64.0"
#define HWMCA_IFA_CURRENT_CAPPED_SUFFIX            "65.0"
#define HWMCA_IFL_WEIGHT_SUFFIX                    "66.0"
#define HWMCA_IFL_CAPPED_SUFFIX                    "67.0"
#define HWMCA_IFL_MINIMUM_WEIGHT_SUFFIX            "68.0"
#define HWMCA_IFL_MAXIMUM_WEIGHT_SUFFIX            "69.0"
#define HWMCA_IFL_CURRENT_WEIGHT_SUFFIX            "70.0"
#define HWMCA_IFL_CURRENT_CAPPED_SUFFIX            "71.0"
#define HWMCA_ICF_WEIGHT_SUFFIX                    "72.0"
#define HWMCA_ICF_CAPPED_SUFFIX                    "73.0"
#define HWMCA_ICF_MINIMUM_WEIGHT_SUFFIX            "74.0"
#define HWMCA_ICF_MAXIMUM_WEIGHT_SUFFIX            "75.0"
#define HWMCA_ICF_CURRENT_WEIGHT_SUFFIX            "76.0"
#define HWMCA_ICF_CURRENT_CAPPED_SUFFIX            "77.0"
#define HWMCA_PROCESSOR_RUNNING_TIME_TYPE          "78.0"
#define HWMCA_PROCESSOR_RUNNING_TIME               "79.0"
#define HWMCA_END_TIMESLICE_IF_WAITSTATE           "80.0"
#define HWMCA_IIP_WEIGHT_SUFFIX                    "81.0"
#define HWMCA_IIP_CAPPED_SUFFIX                    "82.0"
#define HWMCA_IIP_MINIMUM_WEIGHT_SUFFIX            "83.0"
#define HWMCA_IIP_MAXIMUM_WEIGHT_SUFFIX            "84.0"
#define HWMCA_IIP_CURRENT_WEIGHT_SUFFIX            "85.0"
#define HWMCA_IIP_CURRENT_CAPPED_SUFFIX            "86.0"
#define HWMCA_OOCOD_INSTALLED_SUFFIX               "87.0"
#define HWMCA_OOCOD_ACTIVATED_SUFFIX               "88.0"
#define HWMCA_OOCOD_ENABLED_SUFFIX                 "89.0"
#define HWMCA_OOCOD_ACTIVATION_DATE_SUFFIX         "90.0"
#define HWMCA_ACT_GROUP_LIST_SUFFIX                "91.0"
#define HWMCA_ACT_PROFILE_CAPACITY_SUFFIX          "92.0"
#define HWMCA_GROUP_PROFILE_NAME_SUFFIX            "93.0"
#define HWMCA_ACT_PROFILE_LOAD_AT_ACTIVATION_SUFFIX         "94.0"
#define HWMCA_ACT_PROFILE_CENTRAL_STORAGE_SUFFIX            "95.0"
#define HWMCA_ACT_PROFILE_CENTRAL_STORAGE_RESERVED_SUFFIX   "96.0"
#define HWMCA_ACT_PROFILE_EXPANDED_STORAGE_SUFFIX           "97.0"
#define HWMCA_ACT_PROFILE_EXPANDED_STORAGE_RESERVED_SUFFIX  "98.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_CP_SUFFIX           "99.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_CP_RESERVED_SUFFIX  "100.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_IFA_SUFFIX          "101.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_IFA_RESERVED_SUFFIX "102.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_IFL_SUFFIX          "103.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_IFL_RESERVED_SUFFIX "104.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_ICF_SUFFIX          "105.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_ICF_RESERVED_SUFFIX "106.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_IIP_SUFFIX          "107.0"
#define HWMCA_ACT_PROFILE_NUM_DEDICATED_IIP_RESERVED_SUFFIX "108.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_CP_SUFFIX              "109.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_CP_RESERVED_SUFFIX     "110.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_IFA_SUFFIX             "111.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_IFA_RESERVED_SUFFIX    "112.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_IFL_SUFFIX             "113.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_IFL_RESERVED_SUFFIX    "114.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_ICF_SUFFIX             "115.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_ICF_RESERVED_SUFFIX    "116.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_IIP_SUFFIX             "117.0"
#define HWMCA_ACT_PROFILE_NUM_SHARED_IIP_RESERVED_SUFFIX    "118.0"
#define HWMCA_CAPACITY_RECORD_LIST_SUFFIX                   "119.0"
#define HWMCA_PERM_SOFTWARE_MODEL_SUFFIX                    "120.0"
#define HWMCA_PERMBILL_SOFTWARE_MODEL_SUFFIX                "121.0"
#define HWMCA_PERMALL_SOFTWARE_MODEL_SUFFIX                 "122.0"
#define HWMCA_PERM_MSU_SUFFIX                               "123.0"
#define HWMCA_PERMBILL_MSU_SUFFIX                           "124.0"
#define HWMCA_PERMALL_MSU_SUFFIX                            "125.0"
#define HWMCA_GEN_PROCESSOR_NUM_SUFFIX                      "126.0"
#define HWMCA_SAP_PROCESSOR_NUM_SUFFIX                      "127.0"
#define HWMCA_IFA_PROCESSOR_NUM_SUFFIX                      "128.0"
#define HWMCA_IFL_PROCESSOR_NUM_SUFFIX                      "129.0"
#define HWMCA_ICF_PROCESSOR_NUM_SUFFIX                      "130.0"
#define HWMCA_IIP_PROCESSOR_NUM_SUFFIX                      "131.0"
#define HWMCA_DEFECTIVE_PROCESSOR_NUM_SUFFIX                "132.0"
#define HWMCA_SPARE_PROCESSOR_NUM_SUFFIX                    "133.0"
#define HWMCA_PENDING_PROCESSOR_NUM_SUFFIX                  "134.0"
#define HWMCA_RECORD_ID_SUFFIX                              "135.0"
#define HWMCA_RECORD_TYPE_SUFFIX                            "136.0"
#define HWMCA_RECORD_ACTIVATION_STATUS_SUFFIX               "137.0"
#define HWMCA_RECORD_ACTIVATION_DATE_SUFFIX                 "138.0"
#define HWMCA_RECORD_EXPIRE_DATE_SUFFIX                     "139.0"
#define HWMCA_RECORD_ACT_EXPIRE_DATE_SUFFIX                 "140.0"
#define HWMCA_RECORD_MAX_REAL_ACT_DAYS_SUFFIX               "141.0"
#define HWMCA_RECORD_MAX_TEST_ACT_DAYS_SUFFIX               "142.0"
#define HWMCA_RECORD_REM_REAL_ACT_DAYS_SUFFIX               "143.0"
#define HWMCA_RECORD_REM_TEST_ACT_DAYS_SUFFIX               "144.0"
#define HWMCA_CAPACITY_CHANGE_TYPE_SUFFIX                   "145.0"
#define HWMCA_RECORD_CHANGE_TYPE_SUFFIX                     "146.0"
#define HWMCA_RECORD_REM_REAL_COUNT_SUFFIX                  "147.0"
#define HWMCA_RECORD_REM_TEST_COUNT_SUFFIX                  "148.0"
#define HWMCA_CAPACITY_CHANGE_ALLOWED_SUFFIX                "149.0"
#define HWMCA_PSW_SUFFIX                                    "150.0"
#define HWMCA_PROCESSOR_SUFFIX                              "150.1"
#define HWMCA_SCP_INITIATE_RESET_SUFFIX                     "150.2"
#define HWMCA_VERSION_SUFFIX                                "151.0"
#define HWMCA_POWER_VERSION_INFO_SUFFIX                     "152.0"
#define HWMCA_POWER_BUFFER_TAG_SUFFIX                       "153.0"
#define HWMCA_POWER_STATUS_REGISTER_SUFFIX                  "154.0"
#define HWMCA_POWER_EVENT_REGISTER_SUFFIX                   "155.0"
#define HWMCA_POWER_ERROR_REGISTER_SUFFIX                   "156.0"
#define HWMCA_POWER_EXHAUST_HEAT_INDEX_SUFFIX               "157.0"
#define HWMCA_POWER_INLET_TEMP_SUFFIX                       "158.0"
#define HWMCA_POWER_AVG_POWER_SAMPLES_SUFFIX                "159.0"
#define HWMCA_POWER_PEAK_POWER_SAMPLES_SUFFIX               "160.0"
#define HWMCA_ALL_IP_ADDRESSES_SUFFIX                       "161.0"
#define HWMCA_EC_MCL_INFO_SUFFIX                            "162.0"
#define HWMCA_AUTO_SWITCH_ENABLED_SUFFIX                    "163.0"
#define HWMCA_IPL_TOKEN_SUFFIX                              "164.0"
#define HWMCA_SYSPLEX_TIME_STP_INFO_SUFFIX                  "165.0"
#define HWMCA_ACT_PROFILE_STORESTATUS_SUFFIX                "166.0"
#define HWMCA_ACT_PROFILE_LOADTYPE_SUFFIX                   "167.0"
#define HWMCA_CPU_COUNTER_BASIC_ENABLED_SUFFIX              "168.0"
#define HWMCA_CPU_COUNTER_PROBLEMSTATE_ENABLED_SUFFIX       "169.0"
#define HWMCA_CPU_COUNTER_CRYPTOACTIVITY_ENABLED_SUFFIX     "170.0"
#define HWMCA_CPU_COUNTER_EXTENDED_ENABLED_SUFFIX           "171.0"
#define HWMCA_CPU_COUNTER_COPROCGROUP_ENABLED_SUFFIX        "172.0"
#define HWMCA_CPU_SAMPLING_BASIC_ENABLED_SUFFIX             "173.0"
#define HWMCA_CPU_SAMPLING_DIAGNOSIS_ENABLED_SUFFIX         "174.0"
#define HWMCA_PENDING_GEN_PROCESSOR_NUM_SUFFIX              "175.0"
#define HWMCA_PENDING_SAP_PROCESSOR_NUM_SUFFIX              "176.0"
#define HWMCA_PENDING_IFA_PROCESSOR_NUM_SUFFIX              "177.0"
#define HWMCA_PENDING_IFL_PROCESSOR_NUM_SUFFIX              "178.0"
#define HWMCA_PENDING_ICF_PROCESSOR_NUM_SUFFIX              "179.0"
#define HWMCA_PENDING_IIP_PROCESSOR_NUM_SUFFIX              "180.0"
#define HWMCA_ZBX_CHASSIS_LIST_SUFFIX                       "181.0"
#define HWMCA_POWER_BUFFER_SIZE_SUFFIX                      "182.0"
#define HWMCA_ENCRYPT_AES_FUNCTIONS_SUFFIX                  "183.0"
#define HWMCA_ENCRYPT_DEA_FUNCTIONS_SUFFIX                  "184.0"
#define HWMCA_LABEL_POWER_SUFFIX                            "185.0"
#define HWMCA_POWER_SAMPLE_RATE_SUFFIX                      "186.0"
#define HWMCA_PROCESSOR_POWER_MODE_SUFFIX                   "190.0"
#define HWMCA_PROCESSOR_POWER_MODE_SUFFIX2                  "190.1"
#define HWMCA_PROCESSOR_POWER_MODE_LIST_SUFFIX              "191.0"
#define HWMCA_PROCESSOR_POWER_MODE_LIST_SUFFIX2             "191.1"
#define HWMCA_GROUP_PROFILE_CAPACITY_SUFFIX                 "192.0"
#define HWMCA_PROCESSOR_POWER_SAVE_MODE_ALLOWED             "193.0"
#define HWMCA_PROCESSOR_POWER_SAVE_MODE_ALLOWED2            "193.1"
#define HWMCA_POWER_DEWPOINT_SUFFIX                         "194.0"
#define HWMCA_POWER_HUMIDITY_SUFFIX                         "195.0"
#define HWMCA_POWER_CAPPING_SUFFIX                          "196.0"
#define HWMCA_POWER_CAPPING_MINIMUM_SUFFIX                  "197.0"
#define HWMCA_POWER_CAPPING_MAXIMUM_SUFFIX                  "198.0"
#define HWMCA_POWER_CAPPING_ALLOWED                         "199.0"
#define HWMCA_POWER_CAPPING_ENABLED_SUFFIX                  "200.0"
#define HWMCA_LAST_USED_LOAD_ADDR_SUFFIX                    "201.0"
#define HWMCA_LAST_USED_LOAD_PARM_SUFFIX                    "202.0"
#define HWMCA_DESCRIPTION_SUFFIX                            "203.0"
#define HWMCA_OPERATING_MODE_SUFFIX                         "204.0"
#define HWMCA_CLOCK_TYPE_SUFFIX                             "205.0"
#define HWMCA_TIME_OFFSET_DAYS_SUFFIX                       "206.0"
#define HWMCA_TIME_OFFSET_HOURS_SUFFIX                      "207.0"
#define HWMCA_TIME_OFFSET_MINUTES_SUFFIX                    "208.0"
#define HWMCA_TIME_OFFSET_INCREASE_SUFFIX                   "209.0"
#define HWMCA_LICCC_VALIDATION_ENABLED_SUFFIX               "210.0"
#define HWMCA_GLOBAL_PERFORMANCE_DATA_CONTROL_SUFFIX        "211.0"
#define HWMCA_IO_CONFIGURATION_CONTROL_SUFFIX               "212.0"
#define HWMCA_CROSS_PARTITION_AUTHORITY_SUFFIX              "213.0"
#define HWMCA_LOGICAL_PARTITION_ISOLATION_SUFFIX            "214.0"
#define HWMCA_ABS_CAPPED_SUFFIX                             "217.0"
#define HWMCA_ABS_CAP_VALUE_SUFFIX                          "218.0"
#define HWMCA_IFA_ABS_CAPPED_SUFFIX                         "219.0"
#define HWMCA_IFA_ABS_CAP_VALUE_SUFFIX                      "220.0"
#define HWMCA_IFL_ABS_CAPPED_SUFFIX                         "221.0"
#define HWMCA_IFL_ABS_CAP_VALUE_SUFFIX                      "222.0"
#define HWMCA_ICF_ABS_CAPPED_SUFFIX                         "223.0"
#define HWMCA_ICF_ABS_CAP_VALUE_SUFFIX                      "224.0"
#define HWMCA_IIP_ABS_CAPPED_SUFFIX                         "225.0"
#define HWMCA_IIP_ABS_CAP_VALUE_SUFFIX                      "226.0"
#define HWMCA_GROUP_PROFILE_ABS_CAPPED_SUFFIX               "227.0"
#define HWMCA_GROUP_PROFILE_ABS_CAP_VALUE_SUFFIX            "228.0"
#define HWMCA_GROUP_PROFILE_ICF_ABS_CAPPED_SUFFIX           "229.0"
#define HWMCA_GROUP_PROFILE_ICF_ABS_CAP_VALUE_SUFFIX        "230.0"
#define HWMCA_GROUP_PROFILE_IFL_ABS_CAPPED_SUFFIX           "231.0"
#define HWMCA_GROUP_PROFILE_IFL_ABS_CAP_VALUE_SUFFIX        "232.0"
#define HWMCA_GROUP_PROFILE_IIP_ABS_CAPPED_SUFFIX           "233.0"
#define HWMCA_GROUP_PROFILE_IIP_ABS_CAP_VALUE_SUFFIX        "234.0"
#define HWMCA_PROCESSOR_INFORMATION_SUFFIX                  "235.0"
#define HWMCA_LPAR_CONTROLS_SUFFIX                          "236.0"
#define HWMCA_GROUP_CONTROLS_SUFFIX                         "237.0"

/******************************************************************************/
/* Defines for the Hardware Management Console Command Object IDs.            */
/******************************************************************************/
#define HWMCA_ACTIVATE_COMMAND                          "1.3.6.1.4.1.2.6.42.4.1"
#define HWMCA_DEACTIVATE_COMMAND                        "1.3.6.1.4.1.2.6.42.4.2"
#define HWMCA_SEND_OPSYS_COMMAND                        "1.3.6.1.4.1.2.6.42.4.3"
#define HWMCA_RESETNORMAL_COMMAND                       "1.3.6.1.4.1.2.6.42.4.4"
#define HWMCA_START_COMMAND                             "1.3.6.1.4.1.2.6.42.4.5"
#define HWMCA_STOP_COMMAND                              "1.3.6.1.4.1.2.6.42.4.6"
#define HWMCA_PSWRESTART_COMMAND                        "1.3.6.1.4.1.2.6.42.4.7"
#define HWMCA_INITIALIZE_API                            "1.3.6.1.4.1.2.6.42.4.8"
#define HWMCA_TERMINATE_API                             "1.3.6.1.4.1.2.6.42.4.9"
#define HWMCA_LOAD_COMMAND                              "1.3.6.1.4.1.2.6.42.4.10"
#define HWMCA_HW_MESSAGE_REFRESH_COMMAND                "1.3.6.1.4.1.2.6.42.4.11"
#define HWMCA_RESETCLEAR_COMMAND                        "1.3.6.1.4.1.2.6.42.4.12"
#define HWMCA_HW_MESSAGE_DELETE_COMMAND                 "1.3.6.1.4.1.2.6.42.4.13"
#define HWMCA_ACTIVATE_CBU_COMMAND                      "1.3.6.1.4.1.2.6.42.4.14"
#define HWMCA_UNDO_CBU_COMMAND                          "1.3.6.1.4.1.2.6.42.4.15"
#define HWMCA_IMPORT_PROFILE_COMMAND                    "1.3.6.1.4.1.2.6.42.4.16"
#define HWMCA_EXPORT_PROFILE_COMMAND                    "1.3.6.1.4.1.2.6.42.4.17"
#define HWMCA_RESERVE_COMMAND                           "1.3.6.1.4.1.2.6.42.4.18"
#define HWMCA_EXTERNAL_INTERRUPT_COMMAND                "1.3.6.1.4.1.2.6.42.4.19"
#define HWMCA_SCSI_LOAD_COMMAND                         "1.3.6.1.4.1.2.6.42.4.20"
#define HWMCA_SCSI_DUMP_COMMAND                         "1.3.6.1.4.1.2.6.42.4.21"
#define HWMCA_SHUTDOWN_RESTART_COMMAND                  "1.3.6.1.4.1.2.6.42.4.22"
#define HWMCA_ACTIVATE_OOCOD_COMMAND                    "1.3.6.1.4.1.2.6.42.4.23"
#define HWMCA_UNDO_OOCOD_COMMAND                        "1.3.6.1.4.1.2.6.42.4.24"
#define HWMCA_ADD_CAPACITY_COMMAND                      "1.3.6.1.4.1.2.6.42.4.25"
#define HWMCA_REMOVE_CAPACITY_COMMAND                   "1.3.6.1.4.1.2.6.42.4.26"
#define HWMCA_SYSPLEX_TIME_SWAP_CTS_COMMAND             "1.3.6.1.4.1.2.6.42.4.27"
#define HWMCA_SYSPLEX_TIME_SET_STP_CONFIG_COMMAND       "1.3.6.1.4.1.2.6.42.4.28"
#define HWMCA_SYSPLEX_TIME_CHANGE_STP_ONLY_CTN_COMMAND  "1.3.6.1.4.1.2.6.42.4.29"
#define HWMCA_SYSPLEX_TIME_JOIN_STP_ONLY_CTN_COMMAND    "1.3.6.1.4.1.2.6.42.4.30"
#define HWMCA_SYSPLEX_TIME_LEAVE_STP_ONLY_CTN_COMMAND   "1.3.6.1.4.1.2.6.42.4.31"
#define HWMCA_POWER_CONTROL_COMMAND                     "1.3.6.1.4.1.2.6.42.4.32"
#define HWMCA_SYSPLEX_TIME_SET_DST_COMMAND              "1.3.6.1.4.1.2.6.42.4.33"
#define HWMCA_LOAD_FROM_CDROM_COMMAND                   "1.3.6.1.4.1.2.6.42.4.99"
#define HWMCA_CORRELATED_COMMAND                        "1.3.6.1.4.1.2.6.42.4.100"

#define HWMCA_ACTIVATE_COMMAND_SUFFIX                  "1"
#define HWMCA_DEACTIVATE_COMMAND_SUFFIX                "2"
#define HWMCA_SEND_OPSYS_COMMAND_SUFFIX                "3"
#define HWMCA_RESETNORMAL_COMMAND_SUFFIX               "4"
#define HWMCA_START_COMMAND_SUFFIX                     "5"
#define HWMCA_STOP_COMMAND_SUFFIX                      "6"
#define HWMCA_PSWRESTART_COMMAND_SUFFIX                "7"
#define HWMCA_INITIALIZE_API_SUFFIX                    "8"
#define HWMCA_TERMINATE_API_SUFFIX                     "9"
#define HWMCA_LOAD_COMMAND_SUFFIX                      "10"
#define HWMCA_HW_MESSAGE_REFRESH_COMMAND_SUFFIX        "11"
#define HWMCA_RESETCLEAR_COMMAND_SUFFIX                "12"
#define HWMCA_HW_MESSAGE_DELETE_COMMAND_SUFFIX         "13"
#define HWMCA_ACTIVATE_CBU_COMMAND_SUFFIX              "14"
#define HWMCA_UNDO_CBU_COMMAND_SUFFIX                  "15"
#define HWMCA_IMPORT_PROFILE_COMMAND_SUFFIX            "16"
#define HWMCA_EXPORT_PROFILE_COMMAND_SUFFIX            "17"
#define HWMCA_RESERVE_COMMAND_SUFFIX                   "18"
#define HWMCA_EXTERNAL_INTERRUPT_COMMAND_SUFFIX        "19"
#define HWMCA_SCSI_LOAD_COMMAND_SUFFIX                 "20"
#define HWMCA_SCSI_DUMP_COMMAND_SUFFIX                 "21"
#define HWMCA_SHUTDOWN_RESTART_COMMAND_SUFFIX          "22"
#define HWMCA_ACTIVATE_OOCOD_COMMAND_SUFFIX            "23"
#define HWMCA_UNDO_OOCOD_COMMAND_SUFFIX                "24"
#define HWMCA_ADD_CAPACITY_COMMAND_SUFFIX              "25"
#define HWMCA_REMOVE_CAPACITY_COMMAND_SUFFIX           "26"
#define HWMCA_SYSPLEX_TIME_SWAP_CTS_SUFFIX             "27"
#define HWMCA_SYSPLEX_TIME_SET_STP_CONFIG_SUFFIX       "28"
#define HWMCA_SYSPLEX_TIME_CHANGE_STP_ONLY_CTN_SUFFIX  "29"
#define HWMCA_SYSPLEX_TIME_JOIN_STP_ONLY_CTN_SUFFIX    "30"
#define HWMCA_SYSPLEX_TIME_LEAVE_STP_ONLY_CTN_SUFFIX   "31"
#define HWMCA_POWER_CONTROL_COMMAND_SUFFIX             "32"
#define HWMCA_LOAD_FROM_CDROM_COMMAND_SUFFIX           "99"
#define HWMCA_CORRELATED_COMMAND_SUFFIX                "100"

/******************************************************************************/
/* Defines for the Hardware Management Console Message Event Types.           */
/******************************************************************************/
#define HWMCA_HARDWARE_MESSAGE         1
#define HWMCA_OPSYS_MESSAGE            2

/******************************************************************************/
/* Defines for the CPC Managed Object Degraded Indicator.                     */
/******************************************************************************/
#define HWMCA_NOT_DEGRADED             0x0000
#define HWMCA_DEGRADED_MEM             0x0001
#define HWMCA_DEGRADED_MBA             0x0002
#define HWMCA_DEGRADED_NODE            0x0004
#define HWMCA_DEGRADED_RING            0x0008
#define HWMCA_DEGRADED_CBU             0x0010
#define HWMCA_DEGRADED_MRU             0x0020
#define HWMCA_DEGRADED_AMBIENT         0x0040
#define HWMCA_DEGRADED_MRU_IML         0x0080

/******************************************************************************/
/* Defines for the Hardware Management Console Status Values.                 */
/******************************************************************************/
#define HWMCA_STATUS_OPERATING           0x00000001
#define HWMCA_STATUS_NOT_OPERATING       0x00000002
#define HWMCA_STATUS_NO_POWER            0x00000004
#define HWMCA_STATUS_NOT_ACTIVATED       0x00000008
#define HWMCA_STATUS_EXCEPTIONS          0x00000010
#define HWMCA_STATUS_STATUS_CHECK        0x00000020
#define HWMCA_STATUS_SERVICE             0x00000040
#define HWMCA_STATUS_LINKNOTACTIVE       0x00000080
#define HWMCA_STATUS_POWERSAVE           0x00000100
#define HWMCA_STATUS_SERIOUSALERT        0x00000200
#define HWMCA_STATUS_ALERT               0x00000400
#define HWMCA_STATUS_ENVALERT            0x00000800
#define HWMCA_STATUS_SERVICE_REQ         0x00001000
#define HWMCA_STATUS_DEGRADED            0x00002000
#define HWMCA_STATUS_STORAGE_EXCEEDED    0x01000000
#define HWMCA_STATUS_LOGOFF_TIMEOUT      0x02000000
#define HWMCA_STATUS_FORCED_SLEEP        0x04000000
#define HWMCA_STATUS_IMAGE_NOT_OPERATING 0x08000000
#define HWMCA_STATUS_IMAGE_NOT_ACTIVATED 0x10000000
#define HWMCA_STATUS_IMAGE_NOT_CAPABLE   0x20000000
#define HWMCA_STATUS_UNKNOWN             0x40000000

/******************************************************************************/
/* Defines for the Hardware Management Console IML Mode Values.               */
/******************************************************************************/
#define HWMCA_IML_ESA390_MODE            1
#define HWMCA_IML_S370_MODE              2
#define HWMCA_IML_FM_MODE                6
#define HWMCA_IML_FMAE_MODE              7
#define HWMCA_IML_HM_MODE                8
#define HWMCA_IML_HMEA_MODE              9
#define HWMCA_IML_HMEX_MODE             10
#define HWMCA_IML_LPAR_MODE             11
#define HWMCA_IML_ESA390TPF_MODE        12
#define HWMCA_IML_CF_PROD_MODE          13
#define HWMCA_IML_FMEX_MODE             14
#define HWMCA_IML_HMAS_MODE             15
#define HWMCA_IML_LINUXO_MODE           16
#define HWMCA_IML_ZVM_MODE              18
#define HWMCA_IML_ZAWARE_MODE           20
#define HWMCA_IML_ZACI_MODE             20

/******************************************************************************/
/* Defines for the Image Activation Profile Operating Mode Values.            */
/******************************************************************************/
#define HWMCA_ESA390_OPERATING_MODE            1
#define HWMCA_ESA390TPF_OPERATING_MODE         2
#define HWMCA_CF_OPERATING_MODE                3
#define HWMCA_LINUX_OPERATING_MODE             4
#define HWMCA_FMEX_OPERATING_MODE              5
#define HWMCA_HMEX_OPERATING_MODE              6
#define HWMCA_HMAS_OPERATING_MODE              7
#define HWMCA_ZVM_OPERATING_MODE               8
#define HWMCA_ZAWARE_OPERATING_MODE            9
#define HWMCA_ZACI_OPERATING_MODE              9

/******************************************************************************/
/*Defines for the Hardware Management Console Image Profile Clock Type Values.*/
/******************************************************************************/
#define HWMCA_CLOCK_TYPE_STANDARD 0
#define HWMCA_CLOCK_TYPE_LPAR     1

/******************************************************************************/
/* Defines for the Hardware Management Console IPL Type Values.               */
/******************************************************************************/
#define HWMCA_IPLTYPE_STANDARD           1
#define HWMCA_IPLTYPE_SCSI               2
#define HWMCA_IPLTYPE_SCSIDUMP           3

/******************************************************************************/
/* Defines for the Hardware Management Console Load Type Values.              */
/******************************************************************************/
#define HWMCA_LOADTYPE_NORMAL             0
#define HWMCA_LOADTYPE_CLEAR              1

/******************************************************************************/
/* Defines for the Hardware Management Console Object Type Values.            */
/******************************************************************************/
#define HWMCA_CPC_GROUP                  1
#define HWMCA_CPC_IMAGE_GROUP            2
#define HWMCA_CPC_USER_GROUP             3
#define HWMCA_CPC_IMAGE_USER_GROUP       4
#define HWMCA_CPC_OBJECT                 5
#define HWMCA_CPC_IMAGE_OBJECT           6
#define HWMCA_CF_OBJECT                  7
#define HWMCA_ACT_PROFILE_RESET          8
#define HWMCA_ACT_PROFILE_IMAGE          9
#define HWMCA_ACT_PROFILE_LOAD           10
#define HWMCA_ACT_PROFILE_GROUP          11
#define HWMCA_CAPACITY_RECORD            12
#define HWMCA_VM_GROUP                   13
#define HWMCA_VM_OBJECT                  14
#define HWMCA_ZBX_GROUP                  15
#define HWMCA_ZBX_OBJECT                 16
#define HWMCA_ZBX_CHASSIS_OBJECT         17

/******************************************************************************/
/* Defines for the Hardware Management Console Shutdown/Restart Types.        */
/******************************************************************************/
#define HWMCA_RESTART_APPLICATION            1
#define HWMCA_RESTART_CONSOLE                2
#define HWMCA_SHUTDOWN_CONSOLE               3
#define HWMCA_RESTART_APPLICATION_ALTERNATE  4
#define HWMCA_RESTART_CONSOLE_ALTERNATE      5
#define HWMCA_SHUTDOWN_CONSOLE_ALTERNATE     6

/******************************************************************************/
/* Defines for the Hardware Management Console Ended Event Reasons.           */
/******************************************************************************/
#define HWMCA_ENDED_USER                     1
#define HWMCA_ENDED_AUTOMATION               2
#define HWMCA_ENDED_OTHER                    3

/******************************************************************************/
/* Defines for the Hardware Management Console Processor Running Time types.  */
/******************************************************************************/
#define HWMCA_DETERMINED_SYSTEM              0
#define HWMCA_DETERMINED_USER                1

/******************************************************************************/
/* Defines for the type of capacity record.                                   */
/******************************************************************************/
#define HWMCA_CAPACITY_RECORD_TYPE_CBU           1
#define HWMCA_CAPACITY_RECORD_TYPE_OOCOD         2
#define HWMCA_CAPACITY_RECORD_TYPE_PLANNED_EVENT 3
#define HWMCA_CAPACITY_RECORD_TYPE_LOANER        4

/******************************************************************************/
/* Defines for the activation status of a capacity record.                    */
/******************************************************************************/
#define HWMCA_CAPACITY_RECORD_STATUS_NOT_ACTIVATED    1
#define HWMCA_CAPACITY_RECORD_STATUS_REAL             2
#define HWMCA_CAPACITY_RECORD_STATUS_TEST             3
#define HWMCA_CAPACITY_RECORD_STATUS_CAN_BE_ACTIVATED 4

/******************************************************************************/
/* Defines for the type of change for a HWMCA_EVENT_CAPACITY_CHANGE event.    */
/******************************************************************************/
#define HWMCA_CAPACITY_FENCED_BOOK                 0
#define HWMCA_CAPACITY_DEFECTIVE_PROCESSOR         1
#define HWMCA_CAPACITY_CONCURRENT_BOOK_REPLACE     2
#define HWMCA_CAPACITY_CONCURRENT_BOOK_ADD         3
#define HWMCA_CAPACITY_CHECK_STOP                  4
#define HWMCA_CAPACITY_CHANGES_ALLOWED             5
#define HWMCA_CAPACITY_CHANGES_NOT_ALLOWED         6

/******************************************************************************/
/* Defines for the type of change for a HWMCA_EVENT_CAPACITY_RECORD_CHANGE    */
/* event.                                                                     */
/******************************************************************************/
#define HWMCA_CAPACITY_RECORD_ADD         0
#define HWMCA_CAPACITY_RECORD_DELTA       1
#define HWMCA_CAPACITY_RECORD_DELETE      2
#define HWMCA_CAPACITY_RECORD_ACCOUNTING  3
#define HWMCA_CAPACITY_ACTIVATION_LEVEL   4
#define HWMCA_CAPACITY_PRIORITY_PENDING   5
#define HWMCA_CAPACITY_RECORD_OTHER       6

#define HWMCA_SECURITY_VERSION2           2
#define HWMCA_SECURITY_VERSION3           3
#pragma pack(1)
/******************************************************************************/
/* Hardware Management Console SNMP Target Structure                          */
/******************************************************************************/
struct HWMCA_SNMP_TARGET_S {
   PVOID                 pHost;        /* A pointer to a null terminated      */
                                       /* string specifying the host name or  */
                                       /* internet address for the target     */
                                       /* Hardware Management Console.        */
                                       /*                                     */
   CHAR szCommunity[HWMCA_MAX_COMMUNITY_LEN]; /* Community name to be used    */
                                       /* for requests.                       */
   UINT ulSecurityVersion;             /* Security version used v2c or v3     */

   CHAR szUsername[HWMCA_MAX_USERNAME_LEN]; /* Username to be used for v3 auth */

   CHAR szPassword[HWMCA_MAX_USERNAME_LEN]; /* Password to be used for v3 auth */

   UINT ulReserved;                    /* Reserved field.                     */
};

typedef struct HWMCA_SNMP_TARGET_S HWMCA_SNMP_TARGET_T;
typedef HWMCA_SNMP_TARGET_T  *     HWMCA_SNMP_TARGET_P;
#define HWMCA_SNMP_TARGET_SIZE sizeof(HWMCA_SNMP_TARGET_T)

/******************************************************************************/
/* Hardware Management Console Initialize Structure                           */
/******************************************************************************/
struct HWMCA_INITIALIZE_S {
   PVOID                 pTarget;      /* Pointer to data specifying the      */
                                       /* target Hardware Management Console  */
                                       /* for the request.                    */
                                       /*                                     */
                                       /* For the SNMP APIs, this is an       */
                                       /* HWMCA_SNMP_TARGET_S structure.      */
                                       /*                                     */
   UINT                  ulEventMask;  /* A mask specifying the event         */
                                       /* notifications that the application  */
                                       /* wants to register for.              */
                                       /*                                     */
                                       /* - HWMCA_EVENT_COMMAND_RESPONSE      */
                                       /* - HWMCA_EVENT_MESSAGE               */
                                       /* - HWMCA_EVENT_STATUS_CHANGE         */
                                       /* - HWMCA_EVENT_NAME_CHANGE           */
                                       /* - HWMCA_EVENT_ACTIVATE_PROF_CHANGE  */
                                       /* - HWMCA_EVENT_CREATED               */
                                       /* - HWMCA_EVENT_DESTROYED             */
                                       /* - HWMCA_EVENT_EXCEPTION_STATE       */
                                       /* - HWMCA_EVENT_ENDED                 */
                                       /* - HWMCA_EVENT_HARDWARE_MESSAGE      */
                                       /* - HWMCA_EVENT_OPSYS_MESSAGE         */
                                       /* - HWMCA_EVENT_NO_REFRESH_MESSAGE    */
                                       /*                                     */
   ULONG                 ulReserved;   /* Must be zero.                       */
   union {
      struct {
#ifdef WIN32
		 SOCKET          iAgentSocket; /* Socket used to communicate with the */

#else
         INT             iAgentSocket; /* Socket used to communicate with the */
#endif
                                       /* SNMP agent on the target Hardware   */
                                       /* Management Console.                 */
         UINT            ulInetAddr;   /* Internet address for the SNMP agent.*/

         UINT            uiSecVersion;

         CHAR szCommunity[HWMCA_MAX_COMMUNITY_LEN]; /* Community name to be   */
                                       /* used for requests.                  */
         struct {
            unsigned char bAuthEngineId[HWMCA_MAX_ID_LEN]; // Don't know what the real max is supposed to be
            UINT ulAuthEngineIdLength;
            CHAR szUsername[HWMCA_MAX_USERNAME_LEN];
            CHAR szPassword[HWMCA_MAX_USERNAME_LEN];
            UINT ulAuthEngineBoots;
            UINT ulAuthEngineTime;
            UINT ulMsgId;
            unsigned char bPrivateKey[16];
            UINT uiSalt;
         } v3;
      } snmp;
   } protocol;
};

typedef struct HWMCA_INITIALIZE_S HWMCA_INITIALIZE_T;
typedef HWMCA_INITIALIZE_T  *     HWMCA_INITIALIZE_P;
#define HWMCA_INITIALIZE_SIZE sizeof(HWMCA_INITIALIZE_T)

/******************************************************************************/
/* Hardware Management Console Data Type Structure                            */
/******************************************************************************/
struct HWMCA_DATATYPE_S {
   UCHAR                 ucType;       /* Type of the data:                   */
                                       /*  - HWMCA_TYPE_SEQUENCE              */
                                       /*  - HWMCA_TYPE_INTEGER               */
                                       /*  - HWMCA_TYPE_OCTETSTRING           */
                                       /*  - HWMCA_TYPE_NULL                  */
                                       /*  - HWMCA_TYPE_OBJECTID              */
                                       /*  - HWMCA_TYPE_IPADDRESS             */
   ULONG                 ulLength;     /* Length of the data.                 */
   PVOID                 pData;        /* Pointer to the data itself.         */
   struct HWMCA_DATATYPE_S *pNext;     /* Pointer to next data type structure */
};

typedef struct HWMCA_DATATYPE_S HWMCA_DATATYPE_T;
typedef HWMCA_DATATYPE_T  *     HWMCA_DATATYPE_P;
#define HWMCA_DATATYPE_SIZE sizeof(HWMCA_DATATYPE_T)

/******************************************************************************/
/* Hardware Management Console Variable Binding Structure                     */
/******************************************************************************/
struct HWMCA_VARBIND_S {
   UCHAR                   ucType;     /* Type of the data:                   */
                                       /*  - HWMCA_TYPE_SEQUENCE              */
                                       /*  - HWMCA_TYPE_INTEGER               */
                                       /*  - HWMCA_TYPE_OCTETSTRING           */
                                       /*  - HWMCA_TYPE_NULL                  */
                                       /*  - HWMCA_TYPE_OBJECTID              */
                                       /*  - HWMCA_TYPE_IPADDRESS             */
   ULONG                   status;     /* Error status value.                 */
   ULONG                   ulLength;   /* Length of the data.                 */
   PVOID                   pData;      /* Pointer to the data itself.         */
   PSZ                     pszOid;     /* Pointer to the object identifier    */
   struct HWMCA_VARBIND_S *pNext;      /* Pointer to next data type structure */
};

typedef struct HWMCA_VARBIND_S HWMCA_VARBIND_T;
typedef HWMCA_VARBIND_T  *     HWMCA_VARBIND_P;
#define HWMCA_VARBIND_SIZE sizeof(HWMCA_VARBIND_T)

/******************************************************************************/
/* Hardware Management Console Event Qualifier Structure                      */
/******************************************************************************/
struct HWMCA_EVENT_QUALIFIER_S {
   unsigned int ulEventMask;           /* Event mask for qualifier            */
   unsigned int ulType;                /* Qualifier type                      */
   union {
      char szName[256];                /* Image name for OS msgs events       */
      unsigned int number;             /* Number value for an event           */
      char cReserved[256];             /* Reserved space                      */
   } type;                             /* union of qualifier data             */
   struct HWMCA_EVENT_QUALIFIER_S *pNext;/* Pointer to next qualifier struct  */
};

typedef struct HWMCA_EVENT_QUALIFIER_S HWMCA_EVENT_QUALIFIER_T;
typedef HWMCA_EVENT_QUALIFIER_T  *     HWMCA_EVENT_QUALIFIER_P;
#define HWMCA_EVENT_QUALIFIER_SIZE sizeof(HWMCA_EVENT_QUALIFIER_T)

#define HWMCA_QUALIFIER_TYPE_NAME      0x00000001
#define HWMCA_QUALIFIER_TYPE_NUMBER    0x00000002

#pragma pack()

#ifdef __cplusplus
extern "C" {
#endif
/******************************************************************************/
/* Hardware Management Console Data Exchange Function Prototypes              */
/******************************************************************************/
extern ULONG EXPORTTYPE HwmcaRegister (
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
       UINT,                    /* New event mask to be used                 */
       HWMCA_EVENT_QUALIFIER_P,  /* New event qualifiers to be used           */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaInitialize(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaGet(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       PSZ,                      /* Pointer to null terminated object ID      */
                                 /* string.                                   */
       PVOID,                    /* Pointer to an output buffer for the       */
                                 /* returned data.                            */
       ULONG,                    /* Size of the output buffer.                */
       PULONG,                   /* Pointer to an area where the number of    */
                                 /* total bytes needed for this Get request   */
                                 /* is returned.                              */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaGetNext(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       PSZ,                      /* Pointer to null terminated object ID      */
                                 /* string.                                   */
       PVOID,                    /* Pointer to an output buffer for the       */
                                 /* returned data.                            */
       ULONG,                    /* Size of the output buffer.                */
       PULONG,                   /* Pointer to an area where the number of    */
                                 /* total bytes needed for this Get request   */
                                 /* is returned.                              */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaGetBulk(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       HWMCA_DATATYPE_P,         /* Pointer to a linked list of               */
                                 /* HWMCA_DATATYPE_T structures used to       */
                                 /* specify the object IDs to use in the      */
                                 /* GetBulk request.                          */
       UINT,                     /* Count of non-repeaters for the request.   */
       UINT,                     /* Maximum repititions for the request.      */
       PVOID,                    /* Pointer to an output buffer for the       */
                                 /* returned data.                            */
       ULONG,                    /* Size of the output buffer.                */
       PULONG,                   /* Pointer to an area where the number of    */
                                 /* total bytes needed for this Get request   */
                                 /* is returned.                              */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaEnhancedGet(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       HWMCA_VARBIND_P,          /* Pointer to a linked list of               */
                                 /* HWMCA_VARBIND_T structures used to        */
                                 /* specify the object IDs to use in the      */
                                 /* Get request.                              */
       PVOID,                    /* Pointer to an output buffer for the       */
                                 /* returned data.                            */
       ULONG,                    /* Size of the output buffer.                */
       PULONG,                   /* Pointer to an area where the number of    */
                                 /* total bytes needed for this Get request   */
                                 /* is returned.                              */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaSet(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       PSZ,                      /* Pointer to null terminated object ID      */
                                 /* string.                                   */
       HWMCA_DATATYPE_P,         /* Pointer to a linked list of               */
                                 /* HWMCA_DATATYPE_T structures used to       */
                                 /* represent the data.                       */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaEnhancedSet(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       HWMCA_VARBIND_P,          /* Pointer to a linked list of               */
                                 /* HWMCA_VARBIND_T structures used to        */
                                 /* specify the object IDs to use in the      */
                                 /* Set request.                              */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaWaitEvent(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       PVOID,                    /* Pointer to an output buffer for the       */
                                 /* returned data.                            */
       ULONG,                    /* Size of the output buffer.                */
       PULONG,                   /* Pointer to an area where the number of    */
                                 /* total bytes needed for this Get request   */
                                 /* is returned.                              */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaTerminate(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

extern ULONG EXPORTTYPE HwmcaCommand(
       HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                 /* structure.                                */
       PSZ,                      /* Pointer to null terminated object ID      */
                                 /* string that the command target.           */
       PSZ,                      /* Pointer to null terminated object ID      */
                                 /* string that command identifier.           */
       HWMCA_DATATYPE_P,         /* Pointer to a linked list of               */
                                 /* HWMCA_DATATYPE_T structures used to       */
                                 /* represent the argument data.              */
       ULONG);                   /* Time to wait for the next event           */
                                 /* notification (in milliseconds).           */

ULONG EXPORTTYPE HwmcaCorrelatedCommand(
      HWMCA_INITIALIZE_P,       /* Pointer to data exchange initialization   */
                                /* structure.                                */
      PSZ,                      /* Pointer to null terminated object ID      */
                                /* string that the command target.           */
      PSZ,                      /* Pointer to null terminated object ID      */
                                /* string that command identifier.           */
      HWMCA_DATATYPE_P,         /* Pointer to a linked list of               */
                                /* HWMCA_DATATYPE_T structures used to       */
                                /* represent the argument data.              */
      ULONG,                    /* Time to wait for the next event           */
                                /* notification (in milliseconds).           */
      void *,                   /* Pointer to correlator data.               */
      unsigned int);            /* Size of correlator data.                  */

extern ULONG EXPORTTYPE HwmcaBuildId(
       PSZ,                      /* Pointer to a buffer where the built object*/
                                 /* identifier string is to be placed.        */
       PSZ,                      /* Pointer to the prefix string to be used   */
                                 /* for the object identifier to be built.    */
                                 /*  - HWMCA_CONSOLE_ID                       */
                                 /*  - HWMCA_CFG_CPC_GROUP_ID                 */
                                 /*  - HWMCA_CFG_CPC_ID                       */
                                 /*  - HWMCA_CPC_IMAGE_GROUP_ID               */
                                 /*  - HWMCA_CPC_IMAGE_ID                     */
                                 /*  - HWMCA_GROUPS_GROUP_ID                  */
       PSZ,                      /* Pointer to the attribute suffix string to */
                                 /* be used for the object identifier to be   */
                                 /* build.  This can be specified as NULL,    */
                                 /* when building an ID for an object itself, */
                                 /* as opposed to an attribute object ID.     */
       PSZ,                      /* Pointer to the Group name to be used for  */
                                 /* building the object identifier.  This can */
                                 /* be specified as NULL, when building an ID */
                                 /* for a predefined group or an object from  */
                                 /* a predefined group.                       */
       PSZ);                     /* Pointer to the Object name to be used for */
                                 /* building the object identifier.  This can */
                                 /* be specified as NULL, when building an ID */
                                 /* for a group object.                       */

extern ULONG EXPORTTYPE HwmcaBuildAttributeId(
       PSZ,                      /* Pointer to a buffer where the built object*/
                                 /* identifier string for the attribute is to */
                                 /* be placed.                                */
       PSZ,                      /* Pointer to the object identifier for the  */
                                 /* object for which the attribute identifier */
                                 /* is to be built.                           */
       PSZ);                     /* Pointer to the attribute suffix string to */
                                 /* be used for the attribute identifier to be*/
                                 /* build.                                    */
#if defined(MVS) || defined(__VM__)
extern ULONG EXPORTTYPE HwmcaConvert(
       char *,                   /* target character set                      */
       char *,                   /* source character set (NULL for current)   */
       char *,                   /* source data to be converted               */
       size_t,                   /* length of input data to be cnverted       */
       char *,                   /* output data buffer for converted data     */
       size_t);                  /* size of output data buffer                */
#endif
#ifdef __cplusplus
}
#endif

#endif
